<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Travel Base Pro
 * @since Travel Base Pro 1.0.0
 * @return array An array of default values
 */

function travel_base_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$travel_base_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#ff8121',
		'header_tagline_color'			=> '#888',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#000',
		'colorscheme'					=> 'default',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'          	 	=> esc_html__( 'Read More', 'travel-base-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'travel-base-pro' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'Main Slider,Popular Destination,Trip Search,Destinations,Call to Action,Services,Featured,Counter,Blog',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'travel-base-pro' ),
		'hide_date' 					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// topbar
		'topbar_section_enable'			=> true,
		'topbar_social_enable'			=> false,
		'topbar_email'					=> 'info@themepalace.com',
		'topbar_phone'					=> esc_html__( '+0 00 000000000', 'travel-base-pro' ),

		// Slider
		'slider_section_enable'			=> true,
		'slider_content_type'			=> 'category',
		'slider_count'					=> 3,
		'slider_btn_label'				=> esc_html__( 'Learn More', 'travel-base-pro' ),
		'slider_second_btn_label'				=> esc_html__( 'Discover More', 'travel-base-pro' ),

		// service
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',

		// Counter
		'counter_section_enable'		=> true,

		// trip search
		'trip_search_section_enable'	=> true,
		'trip_search_title'				=> esc_html__( 'Search your destinations', 'travel-base-pro' ),
		'trip_search_sub_title'			=> esc_html__( 'Just select where you want to go, we take care of the rest.', 'travel-base-pro' ),

		// destinations
		'destinations_section_enable'	=> true,
		'destinations_content_type'		=> 'category',
		'destinations_count'			=> 3,
		'destinations_cat_meta_image_enable' => false,
		'destinations_suffix'			=> esc_html__( 'Tour Available', 'travel-base-pro' ),
		'destinations_btn_title'		=> esc_html__( 'View all destinations', 'travel-base-pro' ),

		// call to action
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'custom',
		'cta_title'						=> esc_html__( 'Travel Base Process', 'travel-base-pro' ),
		'cta_sub_title'					=> esc_html__( 'Just select what you want to do, we take care of the rest.', 'travel-base-pro' ),
		'cta_btn_title'					=> esc_html__( 'Learn More', 'travel-base-pro' ),

		// traveler choice
		'featured_section_enable'	=> true,
		'featured_content_type'		=> 'category',

		// popular destination
		'popular_destination_section_enable'	=> true,
		'popular_destination_content_type'		=> 'category',

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'category',
		'blog_count'					=> 4,
		'blog_title'					=> esc_html__( 'From Our Latest Blog', 'travel-base-pro' ),
		'blog_sub_title'				=> esc_html__( 'Know what happening around us', 'travel-base-pro' ),
		'blog_read_more'				=> esc_html__( 'Read More', 'travel-base-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All', 'travel-base-pro' ),

		
	);

	$output = apply_filters( 'travel_base_pro_default_theme_options', $travel_base_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}