<?php
/**
 * Destinations Section options
 *
 * @package Theme Palace
 * @subpackage Travel Base Pro
 * @since Travel Base Pro 1.0.0
 */

// Add Destinations section
$wp_customize->add_section( 'travel_base_pro_destinations_section', array(
	'title'             => esc_html__( 'Destinations','travel-base-pro' ),
	'description'       => esc_html__( 'Destinations Section options.', 'travel-base-pro' ),
	'panel'             => 'travel_base_pro_front_page_panel',
) );

// Destinations content enable control and setting
$wp_customize->add_setting( 'travel_base_pro_theme_options[destinations_section_enable]', array(
	'default'			=> 	$options['destinations_section_enable'],
	'sanitize_callback' => 'travel_base_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Base_Pro_Switch_Control( $wp_customize, 'travel_base_pro_theme_options[destinations_section_enable]', array(
	'label'             => esc_html__( 'Destinations Section Enable', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_destinations_section',
	'on_off_label' 		=> travel_base_pro_switch_options(),
) ) );

// destinations suffix setting and control
$wp_customize->add_setting( 'travel_base_pro_theme_options[destinations_suffix]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['destinations_suffix'],
) );

$wp_customize->add_control( 'travel_base_pro_theme_options[destinations_suffix]', array(
	'label'           	=> esc_html__( 'Suffix After Trip Count', 'travel-base-pro' ),
	'section'        	=> 'travel_base_pro_destinations_section',
	'active_callback' 	=> 'travel_base_pro_is_destinations_section_enable',
	'type'				=> 'text',
) );

// Destinations category image enable control and setting
$wp_customize->add_setting( 'travel_base_pro_theme_options[destinations_cat_meta_image_enable]', array(
	'default'			=> 	$options['destinations_cat_meta_image_enable'],
	'sanitize_callback' => 'travel_base_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Base_Pro_Switch_Control( $wp_customize, 'travel_base_pro_theme_options[destinations_cat_meta_image_enable]', array(
	'label'             => esc_html__( 'Use Category Meta Image', 'travel-base-pro' ),
	'description'       => esc_html__( 'Note: You can enable background image from category image for Destinations, Activities and Trip Types.', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_destinations_section',
	'on_off_label' 		=> travel_base_pro_switch_options(),
	'active_callback'   => 'travel_base_pro_is_destinations_section_enable',
) ) );


// Destinations count control and setting
$wp_customize->add_setting( 'travel_base_pro_theme_options[destinations_count]', array(
	'default'          	=> $options['destinations_count'],
	'sanitize_callback' => 'travel_base_pro_sanitize_number_range',
	'validate_callback' => 'travel_base_pro_validate_destinations_count',
) );

$wp_customize->add_control( 'travel_base_pro_theme_options[destinations_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travel-base-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 9. Please input the valid number and save. Then refresh the page to see the change.', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_destinations_section',
	'active_callback'   => 'travel_base_pro_is_destinations_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 9,
		'style' => 'width: 100px;'
		),
) );

// Destinations content type control and setting
$wp_customize->add_setting( 'travel_base_pro_theme_options[destinations_content_type]', array(
	'default'          	=> $options['destinations_content_type'],
	'sanitize_callback' => 'travel_base_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_base_pro_theme_options[destinations_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_destinations_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_base_pro_is_destinations_section_enable',
	'choices'			=> travel_base_pro_destinations_content_type(),
) );

for ( $i = 1; $i <= $options['destinations_count']; $i++ ) :
	// banner image setting and control.
	$wp_customize->add_setting( 'travel_base_pro_theme_options[destinations_background_image_' . $i . ']', array(
		'sanitize_callback' => 'travel_base_pro_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travel_base_pro_theme_options[destinations_background_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'travel-base-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'travel-base-pro' ), 500, 500 ),
			'section'     		=> 'travel_base_pro_destinations_section',
			'active_callback'	=> 'travel_base_pro_is_destinations_section_image_enable',
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'travel_base_pro_theme_options[destinations_content_category_' . $i . ']', array(
		'sanitize_callback' => 'travel_base_pro_sanitize_single_category',
	) ) ;

	$wp_customize->add_control( new Travel_Base_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_base_pro_theme_options[destinations_content_category_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Category %d', 'travel-base-pro' ), $i ),
		'section'           => 'travel_base_pro_destinations_section',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'travel_base_pro_is_destinations_section_content_category_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'travel_base_pro_theme_options[destinations_content_trip_types_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Travel_Base_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_base_pro_theme_options[destinations_content_trip_types_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Trip Types %d', 'travel-base-pro' ), $i ),
		'section'           => 'travel_base_pro_destinations_section',
		'taxonomy'			=> 'itinerary_types',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'travel_base_pro_is_destinations_section_content_trip_types_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'travel_base_pro_theme_options[destinations_content_activity_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Travel_Base_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_base_pro_theme_options[destinations_content_activity_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Activities %d', 'travel-base-pro' ), $i ),
		'section'           => 'travel_base_pro_destinations_section',
		'taxonomy'			=> 'activity',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'travel_base_pro_is_destinations_section_content_activity_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'travel_base_pro_theme_options[destinations_content_destination_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Travel_Base_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_base_pro_theme_options[destinations_content_destination_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Destination %d', 'travel-base-pro' ), $i ),
		'section'           => 'travel_base_pro_destinations_section',
		'taxonomy'			=> 'travel_locations',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'travel_base_pro_is_destinations_section_content_destination_enable'
	) ) );

	// destinations hr setting and control
	$wp_customize->add_setting( 'travel_base_pro_theme_options[destinations_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Travel_Base_Pro_Customize_Horizontal_Line( $wp_customize, 'travel_base_pro_theme_options[destinations_hr_'. $i .']',
		array(
			'section'         => 'travel_base_pro_destinations_section',
			'active_callback' => 'travel_base_pro_is_destinations_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// destinations title setting and control
$wp_customize->add_setting( 'travel_base_pro_theme_options[destinations_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['destinations_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_base_pro_theme_options[destinations_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'travel-base-pro' ),
	'section'        	=> 'travel_base_pro_destinations_section',
	'active_callback' 	=> 'travel_base_pro_is_destinations_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_base_pro_theme_options[destinations_btn_title]', array(
		'selector'            => '#destinations .read-more a.btn',
		'settings'            => 'travel_base_pro_theme_options[destinations_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_base_pro_destinations_btn_title_partial',
    ) );
}

// destinations btn url setting and control
$wp_customize->add_setting( 'travel_base_pro_theme_options[destinations_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'travel_base_pro_theme_options[destinations_btn_url]', array(
	'label'           	=> esc_html__( 'Button Link', 'travel-base-pro' ),
	'section'        	=> 'travel_base_pro_destinations_section',
	'active_callback' 	=> 'travel_base_pro_is_destinations_section_enable',
	'type'				=> 'url',
) );