<?php
/**
 * Topbar Section options
 *
 * @package Theme Palace
 * @subpackage Travel Base Pro
 * @since Travel Base Pro 1.0.0
 */

// Add Topbar section
$wp_customize->add_section( 'travel_base_pro_topbar_section', array(
	'title'             => esc_html__( 'Topbar','travel-base-pro' ),
	'description'       => esc_html__( 'Topbar Section options.', 'travel-base-pro' ),
	'panel'             => 'travel_base_pro_front_page_panel',
) );

// Topbar content enable control and setting
$wp_customize->add_setting( 'travel_base_pro_theme_options[topbar_section_enable]', array(
	'default'			=> 	$options['topbar_section_enable'],
	'sanitize_callback' => 'travel_base_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Base_Pro_Switch_Control( $wp_customize, 'travel_base_pro_theme_options[topbar_section_enable]', array(
	'label'             => esc_html__( 'Topbar Section Enable', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_topbar_section',
	'on_off_label' 		=> travel_base_pro_switch_options(),
) ) );

// Topbar social enable control and setting
$wp_customize->add_setting( 'travel_base_pro_theme_options[topbar_social_enable]', array(
	'default'			=> 	$options['topbar_social_enable'],
	'sanitize_callback' => 'travel_base_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Base_Pro_Switch_Control( $wp_customize, 'travel_base_pro_theme_options[topbar_social_enable]', array(
	'label'             => esc_html__( 'Social Menu Enable', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_topbar_section',
	'active_callback' 	=> 'travel_base_pro_is_topbar_section_enable',
	'on_off_label' 		=> travel_base_pro_switch_options(),
) ) );

// topbar email setting and control
$wp_customize->add_setting( 'travel_base_pro_theme_options[topbar_email]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['topbar_email'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_base_pro_theme_options[topbar_email]', array(
	'label'           	=> esc_html__( 'Email ID', 'travel-base-pro' ),
	'section'        	=> 'travel_base_pro_topbar_section',
	'active_callback' 	=> 'travel_base_pro_is_topbar_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_base_pro_theme_options[topbar_email]', array(
		'selector'            => '#top-bar .contact-info .topbar-email a',
		'settings'            => 'travel_base_pro_theme_options[topbar_email]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_base_pro_topbar_email_partial',
    ) );
}

// topbar phone setting and control
$wp_customize->add_setting( 'travel_base_pro_theme_options[topbar_phone]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['topbar_phone'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_base_pro_theme_options[topbar_phone]', array(
	'label'           	=> esc_html__( 'Phone No.', 'travel-base-pro' ),
	'section'        	=> 'travel_base_pro_topbar_section',
	'active_callback' 	=> 'travel_base_pro_is_topbar_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_base_pro_theme_options[topbar_phone]', array(
		'selector'            => '#top-bar .contact-info .topbar-phone a',
		'settings'            => 'travel_base_pro_theme_options[topbar_phone]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_base_pro_topbar_phone_partial',
    ) );
}